examples/tools/completer/mainwindow.cpp
changeset 30 5dc02b23752f
parent 18 2f34d5167611
--- a/examples/tools/completer/mainwindow.cpp	Wed Jun 23 19:07:03 2010 +0300
+++ b/examples/tools/completer/mainwindow.cpp	Tue Jul 06 15:10:48 2010 +0300
@@ -6,41 +6,40 @@
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
-** No Commercial Usage
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** $QT_BEGIN_LICENSE:BSD$
+** You may use this file under the terms of the BSD license as follows:
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
+** "Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are
+** met:
+**   * Redistributions of source code must retain the above copyright
+**     notice, this list of conditions and the following disclaimer.
+**   * Redistributions in binary form must reproduce the above copyright
+**     notice, this list of conditions and the following disclaimer in
+**     the documentation and/or other materials provided with the
+**     distribution.
+**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
+**     the names of its contributors may be used to endorse or promote
+**     products derived from this software without specific prior written
+**     permission.
 **
-**
-**
-**
-**
-**
-**
-**
+** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include <QtGui>
-#include "dirmodel.h"
+#include "fsmodel.h"
 #include "mainwindow.h"
 
 //! [0]
@@ -55,8 +54,8 @@
     modelLabel->setText(tr("Model"));
 
     modelCombo = new QComboBox;
-    modelCombo->addItem(tr("QDirModel"));
-    modelCombo->addItem(tr("QDirModel that shows full path"));
+    modelCombo->addItem(tr("QFileSytemModel"));
+    modelCombo->addItem(tr("QFileSytemModel that shows full path"));
     modelCombo->addItem(tr("Country list"));
     modelCombo->addItem(tr("Word list"));
     modelCombo->setCurrentIndex(0);
@@ -218,17 +217,19 @@
     switch (modelCombo->currentIndex()) {
     default:
     case 0:
-        { // Unsorted QDirModel
-            QDirModel *dirModel = new QDirModel(completer);
-            completer->setModel(dirModel);
+        { // Unsorted QFileSystemModel
+            QFileSystemModel *fsModel = new QFileSystemModel(completer);
+            fsModel->setRootPath("");
+            completer->setModel(fsModel);
             contentsLabel->setText(tr("Enter file path"));
         }
         break;
 //! [11] //! [12]
     case 1:
-        { // DirModel that shows full paths
-            DirModel *dirModel = new DirModel(completer);
-            completer->setModel(dirModel);
+        {   // FileSystemModel that shows full paths
+            FileSystemModel *fsModel = new FileSystemModel(completer);
+            completer->setModel(fsModel);
+            fsModel->setRootPath("");
             contentsLabel->setText(tr("Enter file path"));
         }
         break;